Page 22 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 22

Home

    synagogues on the Sabbath. The Pharisees were likely
    referring to an oral tradition unknown to the common

    people.
    In Matthew 23:15 Jesus condemned the Pharisees for

    ye compass sea and land to make one proselyte, and
    when he is made, ye make him twofold more the child of
    hell than yourselves.

    If the proselyte had been taught the written Law of
    Moses, such a condemnation would not have been likely.
    However, instruction in a secret oral tradition could
    account for evil practices that would merit

    evil

    account for evil practices that would merit
    condemnation. At another time, Jesus may have stopped
    just short of exposing what the Pharisees were secretly
    teaching. This is recorded in Luke 12:1-3:

    that

    would

    merit

    account

    In the mean time, when there were gathered an
    innumerable multitude of people, insomuch that they
    trode one upon another, he began to say unto his
    disciples first of all, Beware ye of the leaven of the
    Pharisees, which is hypocrisy.

    For there is nothing covered, that shall not be
    revealed; neither hid, that shall not be known.

    Therefore whatsoever ye have spoken in darkness
    shall be heard in the light; and that which ye have spoken
    in the ears in closets shall be proclaimed upon the

    1

    17

    Ancient Oral Traditions

    the corrupting of their followers:

    Woe unto you scribes and Pharisees, hypocrites! for

    housetops.